@@ -45,6 +45,9 @@ fn main() {
 
 // Uses code from https://github.com/webview/webview_rust/blob/dev/src/webview.rs
 
+#![allow(dead_code)]
+#![allow(non_camel_case_types)]
+
 use fltk::{prelude::*, *};
 use std::{
     ffi::{CStr, CString},
@@ -52,7 +55,8 @@ use std::{
     os::raw,
     sync::Arc,
 };
-use webview_official_sys as wv;
+mod webview_sys;
+use webview_sys as wv;
 
 pub(crate) trait FlString {
     fn safe_new(s: &str) -> CString;
@@ -127,6 +131,7 @@ impl Webview {
                 pub enum NSWindow {}
                 extern "C" {
                     pub fn make_delegate(child: *mut NSWindow, parent: *mut NSWindow);
+                    pub fn my_close_win(win: *mut NSWindow);
                 }
                 let handle = win.raw_handle();
                 inner = wv::webview_create(debug as i32, handle as _);
@@ -134,9 +139,11 @@ impl Webview {
                 win.draw(move |w| wv::webview_set_size(inner, w.w(), w.h(), 0));
                 let mut topwin =
                     window::Window::from_widget_ptr(win.top_window().unwrap().as_widget_ptr());
-                topwin.set_callback(|_| {
+                let inner = inner.clone();
+                topwin.set_callback(move |t| {
                     if app::event() == enums::Event::Close {
-                        std::process::exit(0);
+                        my_close_win(wv::webview_get_window(inner) as _);
+                        t.hide();
                     }
                 });
             }
@@ -205,6 +212,12 @@ impl Webview {
         }
     }
 
+    /// Set the html content of the weview window
+    pub fn set_html(&mut self, html: &str) {
+        let temp = String::from("data:text/html,") + html;
+        self.navigate(&temp);
+    }
+
     /// Injects JavaScript code at the initialization of the new page
     pub fn init(&mut self, js: &str) {
         let js = CString::safe_new(js);
